# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.

# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
"""tests for the astng source code representation

Copyright (c) 2000-2003 LOGILAB S.A. (Paris, FRANCE).
http://www.logilab.fr/ -- mailto:contact@logilab.fr
"""
__revision__ = "$Id: unittest_astutils.py,v 1.5 2003/09/12 11:54:49 syt Exp $"

import unittest
import sys
import parser
from imp import find_module,load_module
from os import getcwd
from os.path import join

from pprint import pprint
from logilab.common.astutils import cvrtr, \
     get_lhs_consumed_names, get_rhs_consumed_names


class GetrhsconsumednamesFunctionTest(unittest.TestCase):
    def test_known_values_0(self):
        ast = parser.suite("""func(ignore=consider)""").totuple()
        #pprint(cvrtr(ast))
        self.assertEqual(get_rhs_consumed_names(ast), [
            'func', 'consider'])
        
    def test_known_values_1(self):
        ast = parser.suite("""{
    'repository' : str,
    'path' : str,
    'tag' : str,
    'checks': lambda s: [get_checker(w) for w in get_csv(s)],
    'dependencies': lambda s: [get_dependency_info(w) for w in get_csv(s)]
    }""").totuple()
        self.assertEqual(get_rhs_consumed_names(ast), [
            'str', 'str', 'str', 'get_checker', 'get_csv', 'get_dependency_info', 'get_csv'])
        
    def test_known_values_2(self):
        ast = parser.suite("""{
    'repository' : str,
    'path' : s,
    'tag' : w,
    'checks': lambda s: [get_checker(w) for w in get_csv(s)],
    'dependencies': lambda s: [get_dependency_info(w) for w in get_csv(s)]
    }""").totuple()
        self.assertEqual(get_rhs_consumed_names(ast), [
            'str', 's', 'w', 'get_checker', 'get_csv', 'get_dependency_info', 'get_csv'])
        
    def test_known_values_3(self):
        ast = parser.suite("truc.bidule").totuple()
        self.assertEqual(get_rhs_consumed_names(ast), ['truc'])
        
    def test_known_values_4(self):
        ast = parser.suite("config.has_option(MAIN_SECT, option)").totuple()
        self.assertEqual(get_rhs_consumed_names(ast), ['config', 'MAIN_SECT', 'option'])

    def test_known_values_5(self):
        ast = parser.suite("truc[troc]").totuple()
        self.assertEqual(get_rhs_consumed_names(ast), ['truc', 'troc'])
        
    def test_known_values_6(self):
        ast = parser.suite("(truc, troc)").totuple()
        self.assertEqual(get_rhs_consumed_names(ast), ['truc', 'troc'])
        
    def test_known_values_7(self):
        ast = parser.suite("machin in (truc, troc)").totuple()
        self.assertEqual(get_rhs_consumed_names(ast), ['machin', 'truc', 'troc'])
        
class GetlhsconsumednamesFunctionTest(unittest.TestCase):
    def test_known_values_1(self):
        ast = parser.suite("bidule").totuple()
        self.assertEqual(get_lhs_consumed_names(ast), [])

    def test_known_values_2(self):
        ast = parser.suite("bidule, chouette").totuple()
        self.assertEqual(get_lhs_consumed_names(ast), [])

    def test_known_values_3(self):
        ast = parser.suite("truc.bidule").totuple()
        self.assertEqual(get_lhs_consumed_names(ast), ['truc'])
        
    def test_known_values_4(self):
        ast = parser.suite("config.has_option(MAIN_SECT, option)").totuple()
        self.assertEqual(get_lhs_consumed_names(ast), ['config', 'MAIN_SECT', 'option'])
    
def suite():
    """return the unitest suite"""
    loader = unittest.TestLoader()
    testsuite = loader.loadTestsFromModule(sys.modules[__name__])
    return testsuite

def Run(runner=None):
    """run tests"""
    testsuite = suite()
    if runner is None:
        runner = unittest.TextTestRunner()
        # uncomment next line to write tests results in a file
        #runner.__init__(open('tests.log','w+'))    
    return runner.run(testsuite)
        
if __name__ == '__main__':
    Run()
